clear
clear matrix
set scheme s1mono 
set mem 3g
set more off
local cutoff=15

/* This file produces most of the Tables/Figures of the paper, "Vertical Integration and Input Flows."  The only figures/tables
not produced by this file are the ones relating to the sharing of intangible capital (see analysisIntangible.do for the code to make
these tables/figures.  Before running this .do file, the user should run getdata12.sas and getdata345.sas.  */

/* In this document, the following prefixes and suffixes are referenced serveral times:
two, three, threeA: 
These two prefixes reference two different methods to classify a shipment as internal.  If the prefix "two" is used, then a shipment is classified
 as internal if it is shipped from an upstream plant to a downstream plant, where the two plants are at the two ends of a vertical link.  If the prefix
 "three" is used, then a shipment is classifid as internal if it is shipped from an upstream plant to a downstream plant, where the two plants *do not* 
have to be members of a vertical link.  For example, if a firm has an auto parts maker, an auto assembler, a milk manufacturer, and a food wholesaler,
 a shipment from the auto parts maker to the food wholesaler would be classified as internal in the "three" prefix dataset, but not in the "two" prefix 
dataset.  The latter ("three") way of classifying shipments as internal was the method used in the earlier versions of this paper.  The former ("two") 
way of classifying shipments is probably more accurate, so is the baseline method of calculating internal shipments 

Finally, threeA is a robustness check.  In this case, the industries of the sending & receiving establishments are irrelevant.  Any 
shipment for which there is a same-firm establishment in the destination zip code is classified as internal.  

Orig, 10, 50, 10NH, 50NH: These suffixes refer to the way in which vertically-linked industries are defined.  The suffix "orig" refers
 to the original (pre-2011) method  of using only the BEA I/O tables, as in the original draft of Hortacsu and Syverson (2009).  The 10 suffix refers
 to a 1% cutoff rule (vertical industries are defined such that the downstream SIC-industry consumes 1% of the output of the upstream SIC-industry).
  The 50 suffix refers to a 5% cutoff rule.  The NH (No Horizontal) term indicates that i,j pairs of 4-digit SIC industries for which the i,j pair are in
 the same BEA-industry are not included.  

*/

local fig2=0  /* Indicator variable: equals 1 if the user wants to produce Figure A1 of the paper */
local tab8=0 /* ... equals 1 if the user wants to produce Table A4 of the paper */
local tab5=1  /* ... equals 1 if the user wants to produce Tables 3-5, A5-A6 of the paper */
local tab1=0 /* ... equals 1 if the user wants to produce Tables 1 and A2 of the paper */
local tab2=0  /* ... equals 1 if the user wants to produce Table 2 of the paper */
local tab3=0 /* ... equals 1 if the user wants to produce Table A3 of the paper */
local fig1=0  /* ... equals 1 if the user wants to produce Figure 1 of the paper */
local makeVI=0  /* ... equals 1 if the user wants to produce some of the calculations on the subset of 
               establishments that "make their firms" vertically integrated*/
local formle=0  

/* Pull the observations necessary to do the MLE-based robustness check of rows 12-15 of 
  Appendix Table A2.  Also compute the distribution of the number of shipments per
  surveyed establishment. */

if `formle'==1 {
insheet using two10.csv, clear
drop if totalval==0
sort rec_num year
by rec_num year: gen x=_n
keep if rec_num==. | x==1  /* This line appears repeatedly throughout this do file.  It is necessary because, for some shipments,
                           there are multiple candidate downstream plants that our algorithm has identified.  We want to keep only 
                           one per shipment.  Rec_num = . for establishments for which we could not identify any internal shipments. */
drop x
sort lbdnum year
by lbdnum year: gen fi=1 if _n==1
gen viS=1 if rec_num~=.             /* Here, we count the number of shipments that are internal to the firm */
replace viS=0 if rec_num==.
by lbdnum year: egen viSS=sum(viS)
replace viS=viSS
keep lbdnum viS ships year sic4 firmid emp totalval
by lbdnum year: keep if _n==1
save esumForMLE, replace
drop lbdnum year sic4 firmid emp
bys ship  vi: gen count=_N
by ship vi: keep if _n==1
outsheet using formle.csv, replace delim(,)
use esumForMLE, replace
gen coef=.
sum ships, detail
replace coef=r(p10) in 1/1
replace coef=r(p25) in 2/2
replace coef=r(p50) in 3/3
replace coef=r(p75) in 4/4
replace coef=r(p90) in 5/5
replace coef=r(p95) in 6/6
replace coef=r(mean) in 7/7
replace coef=r(N) in 9/9
sum ships [aw=totalv] 
replace coef=r(mean) in 8/8
keep coef
keep in 1/9
outsheet using shipDist.csv, delim(,) replace

}

/* Tables 1/A2 */

if `tab1'==1 {

insheet using firmSizeSmall_92.csv, clear 
keep firmid semp0
gen year=1992
save firmSizeSmall_92, replace
insheet using firmSizeSmall_97.csv, clear
gen year=1997
append using firmSizeSmall_92
sort year firmid
by year firmid: keep if _n==1
save firmSizeSmall, replace

insheet using retailWholesale93Match.csv, clear   /* These are the datasets which tell us which shipments were sent to a wholesaler/retailer within the firm.  */ 
keep rec_num val wei lbdnum year 
sort rec_num year 
by rec_num year: keep if _n==1
save retailWholesale93Match, replace
insheet using retailWholesale97Match.csv, clear
keep rec_num val wei lbdnum year  
sort rec_num year 
by rec_num year: keep if _n==1
save retailWholesale97Match, replace
append using retailWholesale93Match
ren val valRW 
ren wei weiRW, replace
save retailWholesaleMatch, replace
insheet using ipt9297.csv, clear   /* Ipt (which stands for interplant transfers) are taken from the 1992 and 1997 Census of Manufacturers */
bys lbdnum year: keep if _n==1
save ipt9297, replace    

foreach suff in  10   /* 50Orig  10NH 50NH*/ {   /* Loop over the different methodologies for identifying vertically linked industries */

insheet using two`suff'.csv, clear
drop if totalv==0
gen val=vs*cfs_wgt
sort rec_num year val
by rec_num year: keep if _n==1 | rec_num==.
replace cfs_wgt=1 if cfs_wgt==.
gen viS=1 if val>0 & val<.
collapse (sum) val viS (min) totalval emp ships firmid sic4, by(lbdnum year)
gen frac1=val/totalv
sum frac1
gen lafontaine=0
foreach ii in 1221 1222 2086 2865 2869 2911 3143 3241  3714 3724 5171 5172   {   /* These are the 4-digit SIC industries that we identified from Lafontaine and Slade (2007) */
  gen coef`ii'=.
  replace lafontaine=1 if sic4==`ii'
  sum frac1 if sic4==`ii'
  replace coef`ii'= r(mean) in 7/7
  replace coef`ii'= r(N) in 8/8
  sum frac1 if sic4==`ii' [aw=totalval]
  replace coef`ii'= r(mean) in 12/12
  gen esum`ii'=1 if frac1~=. & sic4==`ii'
  sum ships if frac1~=. & sic4==`ii'
  replace coef`ii'=r(sum) in 11/11
}

  gen coef0=.
  sum frac1 if lafontaine==1
  replace coef0= r(mean) in 7/7
  replace coef0= r(N) in 8/8
  sum frac1 if lafontaine==1 [aw=totalval]
  replace coef0= r(mean) in 12/12
  count if frac1==0 &  lafontaine==1
  replace coef0=r(N) in 9/9
  count if viS==ships & lafontaine==1
  gen one0=1 if viS==ships & lafontaine==1 
  replace coef0=r(N) in 10/10
 _pctile frac1 if lafontaine==1, p(9 11  24  26 49 51 74 76  89  91 94 96)  
 /* As we note in the paper, we have to compute the surrounding percentiles of the percentiles of interest.  For instance
  instead of reporting the 75th percentile of the internal share, we report the average of the 74th and 76th percentiles.
  This is to avoid disclosing info about the firms that own the plants that have the 75th percentile internal share */
 
  gen esum0=1 if frac1~=. & lafontaine==1
  forvalues x=1/6 {
    local y=`x'*2-1
    local yy=`x'*2
    replace coef0=1/2*(r(r`y')+r(r`yy')) in `x'/`x'  /* For data confientiality reasons, we cannot report the xth percentile; instead we report the average of the 
                                                     x-1st and x+1st percentiles */
   }
  sum ships if frac1~=. & lafontaine==1
  replace coef0=r(sum) in 11/11

preserve
keep one* esum* firmid frac1 emp lbdnum year
save tab1_esum_`suff'_ind, replace
restore

keep coef* 
keep in 1/12
outsheet using tab1_`suff'_ind.csv, replace 
insheet using two`suff'.csv, clear
drop if totalv==0
merge n:1 rec_num year using retailWholesaleMatch
bys lbdnum year: egen m1=max(_merge)
bys lbdnum year: egen m2=min(_merge)
drop if m1==2 & m2==2
bys rec_num year: gen x=_N
sort rec_num year valRW
by rec_num year: keep if _n==1 | rec_num==.
replace cfs_wgt=1 if cfs_wgt==.
gen val=vs*cfs_wgt
gen wei=weight*cfs_wgt
gen mi1=min(val, valRW)
gen viS=1 if mi1>0 & mi1<.
collapse (sum)  mi1 viS (min) totalval emp ships firmid, by(lbdnum year)
gen frac1=mi1/totalv
sum frac1

gen coef1=.
replace coef1= r(mean) in 7/7
replace coef1= r(N) in 8/8
sum frac1 [aw=totalval]
replace coef1= r(mean) in 12/12
count if frac1==0
replace coef1=r(N) in 9/9
count if viS==ships
gen one10=1  if viS==ships & frac1~=.
/* How many plants have all their value from internal shipments?  Instead of counting the number of plants for which frac1=1, we count the number of plants that have the
 number of shipments equal to the number of internal shipments.  The reason for this is that (because of numerical issues) there are a lot of plants that have frac1 arbitrarity 
close (but not exactly equal) to 1. We store this variable purely for disclosure puroposes (notice how it is included in the esum* dataset).  We need to make sure that there
 are sufficiently many firms with platns that have 100% internal shipments
 */
replace coef1=r(N) in 10/10
_pctile frac1, p(9 11  24  26 49 51 74 76  89  91 94 96)  
gen esum10=1 if frac1~=.
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef1=1/2*(r(r`y')+r(r`yy')) in `x'/`x'  /* For data confientiality reasons, we cannot report the xth percentile; instead we report the average of the 
                                                     x-1st and x+1st percentiles */
}
sum ships if frac1~=.
replace coef1=r(sum) in 11/11
preserve
keep one10 esum10 firmid frac1 emp lbdnum year
save tab1_esum_`suff'_WR, replace
restore
keep coef1 
keep in 1/12
outsheet using tab1_`suff'_WR.csv, replace delim(,)

insheet using upstream`suff'_WSTCC.csv, clear  /* Read in the great circle distances (as computed in getdata12.sas) of actual shipmebnts */
keep cfn  *grt*
gen year=1992
bys cfn : keep if _n==1
save temp2, replace
insheet using upstream`suff'_97_WSTCC.csv, clear
keep cfn  *grt*
gen year=1997
bys cfn : keep if _n==1
append using temp2
save temp2, replace

insheet using upstreamplants`suff'.csv, clear  /* Read in the distances of the nearest downstream plant (for plants that are 
                                           at the upstream ends of vertical relationships) */
keep cfn  distance*
gen year=1992
bys cfn : keep if _n==1
save temp2b, replace
insheet using upstreamplants`suff'_97.csv, clear
keep cfn  distance*
gen year=1997
bys cfn : keep if _n==1
append using temp2b
merge 1:1 cfn year using temp2  /* Merge the two distance-measures together */
drop _merge
save temp2, replace

insheet using three`suff'A.csv, clear     /* Remember the "A" suffix denotes that we define a shipment as internal if there is Any same-firm plant (irrespective of industry) in the destination zip code.  From this dataset, we only want to compare the internal-value share. */
replace year=1992 if year==1993
drop if totalval==0
sort rec_num year
by rec_num year: gen x=_n  /* What is going on here?  If there are multiple plants from the same firm in the destination zip code, then we only 
                            want to keep one observation.  If there are no plants, then the rec_num variable will  have a missing value */
keep if rec_num==. | x==1
drop x
sort lbdnum year
by lbdnum year: gen fi=1 if _n==1  
gen val=vs*cfs_wgt  /* Multiply value (vs) by the sample weight */
gen viS=1 if vs~=.   /* This variable will be equal to 1 if the shipment is classified as internal */
replace viS=0 if vs==.
collapse (sum) val viS (min) ships firmid totalval emp, by(lbdnum year)
gen coef1=.
gen frac1=val/totalval   /* Fraction of value that is comprised of internal shipments */
gen count=0
sum frac1 
replace coef1= r(mean) in 7/7
replace coef1= r(N) in 8/8
sum frac1 [aw=totalval]
replace coef1= r(mean) in 12/12
count if frac1==0
replace coef1=r(N) in 9/9
count if viS==ships
gen one10=1 if viS==ships  & frac1~=.
/* How many plants have all their value from internal shipments?  Instead of counting the number of plants for which frac1=1, we count the number of plants that have the
 number of shipments equal to the number of internal shipments.  The reason for this is that (because of numerical issues) there are a lot of plants that have frac1 arbitrarity 
close (but not exactly equal) to 1. We store this variable purely for disclosure puroposes (notice how it is included in the esum* dataset).  We need to make sure that there
 are sufficiently many firms with platns that have 100% internal shipments
 */
replace coef1=r(N) in 10/10
_pctile frac1, p(9 11  24  26 49 51 74 76  89  91 94 96)  
gen esum10=1 if frac1~=.
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef1=1/2*(r(r`y')+r(r`yy')) in `x'/`x'  /* For data confientiality reasons, we cannot report the xth percentile; instead we report the average of the 
                                                     x-1st and x+1st percentiles */
}
sum ships if frac1~=.
replace coef1=r(sum) in 11/11
preserve
keep one10 esum10 firmid frac1 emp lbdnum year
save tab1_esum_`suff'_threeA, replace
restore
keep coef1 count
keep in 1/12
save tab1_`suff', replace

local count=0

foreach dset in two three {  

insheet using `dset'`suff'C.csv, clear   /* The C suffix refers to classifying all shipments as internal if there is a plant in the destination County (not zip code) in a downstream industry */
replace year=1992 if year==1993
drop if totalval==0
sort rec_num year
by rec_num year: gen x=_n
keep if rec_num==. | x==1
drop x
sort lbdnum year
by lbdnum year: gen fi=1 if _n==1
gen val=vs*cfs_wgt
gen wei=weight*cfs_wgt
gen viSC=1 if rec_num~=.  /* Indicator variable, equals 1 if the shipment is internal to the firm (i.e., there is a same-firm establishment in a downstream industry in the destination County */
replace viSC=0 if rec_num==.

collapse (sum) val viSC  (min) totalval firmid emp, by(lbdnum year)

gen fracC=val/totalval
keep lbdnum year fracC viSC firmid emp
save temp1, replace

insheet using `dset'`suff'.csv, clear
replace year=1992 if year==1993
merge n:1 firmid year using firmSizeSmall
drop if _merge==2
drop _merge
gen bigFirm=(semp0>=10000 & semp0<.)
gen medFirm=(semp0>=1000 & semp0<10000)
gen smmedFirm=(semp0>=500 & semp0<1000)
gen smallFirm=(semp0<500 )
local count=`count'+1
sort rec_num year
by rec_num year: gen x=_n
keep if rec_num==. | x==1
drop x
gen destIsManuf=1 if sicdown>=2000 & sicdown<4000  /* Sometimes we will want to compute shipments that are both internal and for which the destination plant is internal.  In these computations, if there are multiple plants in the destination zip code, where some are manufacturing and some are non-manufacturing, we assume that the shipment goes to the manufacturing establishment. */
gsort lbdnum year -destIsManuf
by lbdnum year: gen fi=1 if _n==1
gen val=vs*cfs_wgt
gen valToManuf=vs*cfs_wgt*destIsManuf
gen wei=weight*cfs_wgt
gen exporter=(abs(log(domesticval/totalval))>.00001)  
gen shipsF=ships if fi==1
bys year: egen medianships=median(shipsF)
drop shipsF
gen big=(ships>=medianships)  /* big is an indicator variable, equaling 1 if the establishment ships more than the median number of shipments */
gen viS=1 if rec_num~=.
replace viS=0 if rec_num==.
gen viSMan=0  
replace viSMan=1 if rec_num~=. & destIsManuf==1
sort lbdnum year
by lbdnum year: egen valS=sum(val)    /* Compute plant-level sums.  We will then keep the first observation per plant */
by lbdnum year: egen valStoManuf=sum(valToManuf)
by lbdnum year: egen weiS=sum(wei)
by lbdnum year: egen viSS=sum(viS)
by lbdnum year: egen viSSMan=sum(viSMan)
replace val=valS
replace valToManuf=valStoManuf
replace wei=weiS
replace viS=viSS
replace viSMan=viSSMan

sum grt_circ if rec_num~=. 
local distInternal=r(mean)
local intShips=r(N)

keep if fi==1
keep lbdnum year val valToManuf wei viS viSMan cfn dist* big exporter totalval totalweight ships sic4 onecountyflag  bigFirm-smallFirm
gen frac1=val/totalval   /*   Value-weighted share of internal shipments */
gen frac2=wei/totalweight  /* Mass-weighted share of internal shipments */
gen frac3=viS/ships   /* Equal-weigthed share of internal shipments */
gen frac4=valToManuf/totalval  /* Value-weighted share of internal shipments where the receiving plant is in manufacturing */
gen count=`count'
forvalues z=1/18 {  /* In the end we will output 14 columns worth of data.  Create these columns here */
  gen coef`z'=.
}

gen nodiff=0
replace nodiff=1 if  sic4==2061 | sic4==2062 | sic4==2062 | sic4==2083 | sic4==2097 | sic4==2895  | sic4==3562 | sic4==2084 | sic4==3253  /* These are the "minimal differentiation idustries of Gollop and Moinahan (sp?)  */ 
replace nodiff=1 if  sic4==3942 | sic4==3269 | sic4==2429 | sic4==3692 | floor(sic4/10)==265 | sic4==2044 | sic4==3299
replace nodiff=1 if  sic4==2397 | sic4==2791 | sic4==2451 | sic4==3398 | sic4==2875 | floor(sic4/10)==211 | sic4==3471
replace nodiff=1 if  floor(sic4/10)==321 | floor(sic4/10)==323 | sic4==3229 | sic4==2439 | sic4==2396 | sic4==2677 | sic4==2642

/* These are the industries that, according to Gollop and Monahan display small amounts of product differentiation */

merge 1:1 lbdnum year using temp1  /* Merge in info about internal shipments where the destination area is county, not zip code */
drop _merge
merge 1:1 cfn year using temp2  /* Merge in distance stuff */
drop if _merge==2
drop _merge

merge 1:1 lbdnum year using ipt9297  /* Merge in CMF-data on interplant transfers (the manufacturing equivalent of internal shipment value */
gen fracCMF=ipt/tvs
drop if frac1==.
/* These computations, the counts and the means, appear in Web Technical Appendix D2 */ 

count if grt_circ_max<distance_min & distance_min~=. & frac1~=.
replace coef14=r(N) in 1/1
count if grt_circ_max<distance_min & frac1==0  & distance_min~=.  & frac1~=.
replace coef14=r(N) in 2/2
sum grt_circ_50 if distance_min~=. & frac1~=., d
replace coef14=r(mean) in 3/3  
sum distance_min if grt_circ_50~=. & frac1~=., d
replace coef14=r(mean) in 4/4
sum grt_circ_mean [aw=ships]
replace coef14=(r(sum)-`distInternal'*`intShips')/(r(sum_w)-`intShips')  in 5/5
replace coef14=`distInternal' in 6/6
count if distance_min~=. & frac1~=.
replace coef14=r(N) in 7/7
gen esum14_A=1 if  distance_min~=.& frac1~=.
gen esum14_B=1 if distance_min~=. & frac1==0 
gen esum14_C=1 if  distance_min~=.& frac1~=. & frac1~=0  & grt_circ_max<distance_min
gen esum14_D=1 if distance_min~=. & frac1==0  & grt_circ_max<distance_min
gen esum14_E=1 if  distance_min~=.& frac1~=. & frac1~=0 & grt_circ_max>distance_min
gen esum14_F=1 if distance_min~=. & frac1==0 & grt_circ_max>distance_min

forvalues z=1/3 {
sum frac`z'
replace coef`z'= r(mean) in 7/7
replace coef`z'= r(N) in 8/8
sum frac`z' [aw=totalval] 
replace coef`z'= r(mean) in 12/12
count if frac`z'==0
replace coef`z'=r(N) in 9/9
count if ships==viS & frac`z'~=.
replace coef`z'=r(N) in 10/10
gen one`z'=1 if viS==ships & frac`z'~=.
_pctile frac`z' , p(9 11  24  26 49 51 74 76  89  91 94 96)
gen esum`z'=1 if frac`z'~=.
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef`z'=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac`z'~=.
replace coef`z'=r(sum) in 11/11
}

/* Here we throw out exporters */

sum frac1 if exporter==0
replace coef4= r(mean) in 7/7
replace coef4= r(N) in 8/8
sum frac1 if exporter==0 [aw=totalval]
replace coef4= r(mean) in 12/12
count if frac1==0 & exporter==0
replace coef4=r(N) in 9/9
count if ships==viS & exporter==0
gen one4=1 if viS==ships & exporter==0 & frac1~=.
replace coef4=r(N) in 10/10
_pctile frac1 if exporter==0 , p(9 11  24  26 49 51 74 76  89  91 94 96)
gen esum4=1 if frac1~=. & exporter==0
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef4=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac1~=. & exporter==0
replace coef4=r(sum) in 11/11

/* Here we throw out wholesalers */

sum frac1 if sic4<5000 | sic4>=5200
replace coef5= r(mean) in 7/7
replace coef5= r(N) in 8/8
sum frac1 if sic4<5000 | sic4>=5200 [aw=totalval]
replace coef5= r(mean) in 12/12
count if frac1==0 & (sic4<5000 | sic4>=5200) 
replace coef5=r(N) in 9/9
count if ships==viS & (sic4<5000 | sic4>=5200) & frac1~=.
replace coef5=r(N) in 10/10
gen one5=1 if viS==ships & (sic4<5000 | sic4>=5200) & frac1~=.
_pctile frac1 if sic4<5000 | sic4>=5200, p(9 11  24  26 49 51 74 76  89  91 94 96)
gen esum5=1 if frac1~=. & (sic4<5000 | sic4>=5200)
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef5=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac1~=. & (sic4<5000 | sic4>=5200)
replace coef5=r(sum) in 11/11

/* Here we look only of the subset of establishments that have the median number of shipment */

sum frac1 if big==1
replace coef6= r(mean) in 7/7
replace coef6= r(N) in 8/8
sum frac1 if big==1 [aw=totalval]
replace coef6= r(mean) in 12/12
count if frac1==0 & big==1
replace coef6=r(N) in 9/9
count if ships==viS & big==1 & frac1~=.
replace coef6=r(N) in 10/10
gen one6=1 if viS==ships & big==1 & frac1~=.
_pctile frac1 if big==1, p(9 11  24  26 49 51 74 76  89  91 94 96)
gen esum6=1 if frac1~=. & big==1
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef6=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac1~=. & big==1
replace coef6=r(sum) in 11/11

/* This is the check that defines a shipment to be internal if the firm contains a 
 downstream-industry establishment in the destination county, not zip code. */ 

sum fracC
replace coef7= r(mean) in 7/7
replace coef7= r(N) in 8/8
sum fracC [aw=totalval]
replace coef7= r(mean) in 12/12
count if fracC==0 
replace coef7=r(N) in 9/9
count if viSC==ships & fracC~=.
gen one7=1 if viSC==ships  & fracC~=.
replace coef7=r(N) in 10/10
gen esum7=1 if fracC~=.
_pctile fracC , p(9 11  24  26 49 51 74 76  89  91 94 96)
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef7=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if fracC~=. 
replace coef7=r(sum) in 11/11

/* This is the Gollop and Monahan check */

sum frac1 if nodiff==1
replace coef8= r(mean) in 7/7
replace coef8= r(N) in 8/8
sum frac1 if nodiff==1 [aw=totalval]
replace coef8= r(mean) in 12/12
count if frac1==0 & nodiff==1
replace coef8=r(N) in 9/9
count if ships==viS & nodiff==1 & frac1~=.
gen one8=1 if viS==ships & nodiff==1 & frac1~=.
replace coef8=r(N) in 10/10
_pctile frac1 if nodiff==1, p(9 11  24  26 49 51 74 76  89  91 94 96)
gen esum8=1 if frac1~=. & nodiff==1
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef8=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac1~=. & nodiff==1
replace coef8=r(sum) in 11/11

sum frac1 if onecountyflag==1  /* Compute distribution of plant-level internal shipment shares for plants in which all the establishments of its firm are 
                                  located in the same county */
replace coef9= r(mean) in 7/7
replace coef9= r(N) in 8/8
count if frac1==0 & onecountyflag==1
replace coef9=r(N) in 9/9 
sum frac1 if onecountyflag==1 [aw=totalval]
replace coef9= r(mean) in 12/12
count if ships==viS & onecountyflag==1 & frac1~=.
replace coef9=r(N) in 10/10
gen one9=1 if viS==ships & onecountyflag==1 & frac1~=.
gen esum9=1 if frac1~=. & onecountyflag==1
_pctile frac1 if onecountyflag==1, p(9 11  24  26 49 51 74 76  89  91 94 96)
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef9=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac1~=. & onecountyflag==1
replace coef9=r(sum) in 11/11

sum fracCMF if _merge==3  /* Here, we want to compute the share of interplant transfers (according to the CMF), for the plants that are also in our baseline sample (which is why we include the if _merge==3 term */
replace coef10= r(mean) in 7/7
replace coef10= r(N) in 8/8
sum fracCMF  if _merge==3  [aw=tvs]
replace coef10= r(mean) in 12/12
count if fracCMF==0 & _merge==3
replace coef10=r(N) in 9/9 
count if ipt==tvs & fracCMF~=. & _merge==3
replace coef10=r(N) in 10/10
gen one10=1 if ipt==tvs & fracCMF~=. & _merge==3
gen esum10=1 if fracCMF~=. & _merge==3
_pctile fracCMF if _merge==3, p(9 11  24  26 49 51 74 76  89  91 94 96)
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef10=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}

sum fracCMF  
replace coef11= r(mean) in 7/7
replace coef11= r(N) in 8/8
sum fracCMF   [aw=tvs]
replace coef11= r(mean) in 12/12
count if fracCMF==0 
replace coef11=r(N) in 9/9 
count if ipt==tvs & fracCMF~=. 
replace coef11=r(N) in 10/10
gen one11=1 if ipt==tvs & fracCMF~=.
gen esum11=1 if fracCMF~=. 
_pctile fracCMF, p(9 11  24  26 49 51 74 76  89  91 94 96)
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef11=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}

sum frac4 if _merge==3 & fracCMF~=.   /* Here we want to compute the fraction of internal shipments, sent to manufacturers, (according to our calculations derived from the CFS), for plants which are also in manufacturing */
replace coef12= r(mean) in 7/7
replace coef12= r(N) in 8/8
sum frac4 [aw=totalval] if _merge==3 & fracCMF~=. 
replace coef12= r(mean) in 12/12
count if frac4==0  & _merge==3 & fracCMF~=.
replace coef12=r(N) in 9/9 
count if ipt==tvs & frac4~=.  & _merge==3 & fracCMF~=.
replace coef12=r(N) in 10/10
gen one12=1 if viSMan==ships  & frac4~=. & _merge==3 & fracCMF~=.
gen esum12=1 if frac4~=. & _merge==3 & fracCMF~=.
_pctile frac4 if _merge==3 & fracCMF~=., p(9 11  24  26 49 51 74 76  89  91 94 96)
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef12=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac4~=. & _merge==3 & fracCMF~=.
replace coef12=r(sum) in 11/11

sum frac1 if _merge==3 & fracCMF~=. 
replace coef13= r(mean) in 7/7
replace coef13= r(N) in 8/8
sum frac1 [aw=totalval] if _merge==3 & fracCMF~=. 
replace coef13= r(mean) in 12/12
count if frac1==0  & _merge==3 & fracCMF~=.
replace coef13=r(N) in 9/9 
count if ipt==tvs & frac1~=.  & _merge==3 & fracCMF~=.
replace coef13=r(N) in 10/10
gen one13=1 if ships==viS & frac1~=. & _merge==3 & fracCMF~=.
gen esum13=1 if frac1~=. & _merge==3 & fracCMF~=.
_pctile frac1 if _merge==3 & fracCMF~=., p(9 11  24  26 49 51 74 76  89  91 94 96)
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef13=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac1~=. & _merge==3 & fracCMF~=.
replace coef13=r(sum) in 11/11

/* The bigFirm, medFirm, smmedFirm, smallFirm checks appear in the final four rows of Table A2 */ 

sum frac1 if bigFirm==1
replace coef15= r(mean) in 7/7
replace coef15= r(N) in 8/8
sum frac1 if bigFirm==1 [aw=totalval]
replace coef15= r(mean) in 12/12
count if frac1==0 & bigFirm==1 
replace coef15=r(N) in 9/9
count if ships==viS & bigFirm==1 & frac1~=.
replace coef15=r(N) in 10/10
gen one15=1 if viS==ships & bigFirm==1 & frac1~=.
_pctile frac1 if bigFirm==1, p(9 11  24  26 49 51 74 76  89  91 94 96)
gen esum15=1 if frac1~=. & bigFirm==1
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef15=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac1~=. & bigFirm==1
replace coef15=r(sum) in 11/11

sum frac1 if medFirm==1
replace coef16= r(mean) in 7/7
replace coef16= r(N) in 8/8
sum frac1 if medFirm==1 [aw=totalval]
replace coef16= r(mean) in 12/12
count if frac1==0 & medFirm==1
replace coef16=r(N) in 9/9
count if ships==viS & medFirm==1 & frac1~=.
replace coef16=r(N) in 10/10
gen one16=1 if viS==ships & medFirm==1 & frac1~=.
_pctile frac1 if medFirm==1, p(9 11  24  26 49 51 74 76  89  91 94 96)
gen esum16=1 if frac1~=. & medFirm==1
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef16=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac1~=. & medFirm==1
replace coef16=r(sum) in 11/11

sum frac1 if smmedFirm==1
replace coef17= r(mean) in 7/7
replace coef17= r(N) in 8/8
sum frac1 if smmedFirm==1 [aw=totalval]
replace coef17= r(mean) in 12/12
count if frac1==0 & smmedFirm==1 
replace coef17=r(N) in 9/9
count if ships==viS & smmedFirm==1 & frac1~=.
replace coef17=r(N) in 10/10
gen one17=1 if viS==ships & smmedFirm==1 & frac1~=.
_pctile frac1 if smmedFirm==1, p(9 11  24  26 49 51 74 76  89  91 94 96)
gen esum17=1 if frac1~=. & smmedFirm==1
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef17=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac1~=. & smmedFirm==1
replace coef17=r(sum) in 11/11

sum frac1 if smallFirm==1
replace coef18= r(mean) in 7/7
replace coef18= r(N) in 8/8
sum frac1 if smallFirm==1 [aw=totalval]
replace coef18= r(mean) in 12/12
count if frac1==0 & smallFirm==1 
replace coef18=r(N) in 9/9
count if ships==viS & smallFirm==1 & frac1~=.
replace coef18=r(N) in 10/10
gen one18=1 if viS==ships & smallFirm==1 & frac1~=.
_pctile frac1 if smallFirm==1, p(9 11  24  26 49 51 74 76  89  91 94 96)
gen esum18=1 if frac1~=. & smallFirm==1
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef18=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac1~=. & smallFirm==1
replace coef18=r(sum) in 11/11

preserve
keep esum* firmid frac* emp one* _merge lbdnum year
save tab1_esum_`suff'_`dset', replace

restore

keep coef* count 
keep in 1/12
append using tab1_`suff'
save tab1_`suff', replace

}

outsheet using tab1_`suff'.csv, replace delim(,)

}
}

/* Figure 1 */
 /* This is the kernel density plot of the firm size distribution for different organizational forms (VI, non-VI + Multi-industry, Single-industry */
if `fig2'==1 { 
foreach suff in  Orig 10  {

insheet using fig2_`suff'.csv, clear
keep if mu==1 & year==1997      /* The plot includes only multi-unit firms */
bys firmid: keep if _n==1
gen group=1 if vi==1  
replace group=2 if vi==0 & industries>1
replace group=3 if industries==1
save esum_fig2_`suff', replace
gen lte=log10(employmentfi)
tabstat lte, by(group) stats(mean N)
graph twoway (kdensity lte if group==1 & lte>log(2), color(black)) (kdensity lte if group==2, lwidth(medthick) lpattern("-") color(black)) (kdensity lte if group==3, lwidth(thick) lpattern("..") color(black)), xtitle("1997 Firm Size Distributions by Organizational Form") xlab(0 "1" 1 "10" 2 "100" 3 "1000" 4 "10,000" 5 "100,000") legend(off) ytitle("Density")
graph export "figVI_2_`suff'.eps", replace 
 }
}

/* Tables of Sector-level internal shares and comparison of CMF to CFS */

if `tab8'==1 { 
local list2 "10 Orig"    /* Here, the 2 or 4 refers to whether the calculations are being formed at the 2 or 4 digit level */
local list4 "10"

local pref2 "two"
local pref4 "two"

insheet using cfs93Small.csv, clear  /* First pull in data from the entire Commodity Flow Survey.  We do this since we want 
                 to know the share of internal shipments in each industry, and not just among plants that we are classifying 
                 to be vertically integrated. */
gen ships=_N
collapse (sum) val (min) sic4 firmid emp ships, by(lbdnum)
gen year=1992
ren val totalval3
save cfsSmall, replace

insheet using cfs97Small.csv, clear 
gen ships=_N
collapse (sum) val (min) sic4 firmid emp ships, by(lbdnum)
ren val totalval3
gen year=1997
append using cfsSmall
ren sic4 sicCFS
save cfsSmall, replace

insheet using ipt9297.csv, clear  /* Read in the data on interplant transfers (originally from the CMF). First, perform the analysis at the 4-digit level.  */
replace ipt=tvs if ipt>tvs
keep if ind>=2000 & ind<=3999
gen iptPos=(ipt>0 & ipt<.)
bys ind: gen plants=_N   
bys ind firmid iptPos: gen first=1 if _n==1  /* Here (we will do something simlar, below, too) we keep industries for which there are sufficiently 
             many firms represented (for data confidentiality reasons).  We want there to be sufficiently many firms that have plants with 0 interplant transfers
             and sufficiently many firms that have plants with positive interplant transfers */
bys ind: egen s1=sum(first*iptPos)
bys ind: egen s2=sum(first*(1-iptPos))
replace s2=. if s2==0
replace s1=. if s1==0
keep if s1>=`cutoff' & s2>=`cutoff' 

preserve
keep firmid ind iptPos tvs lbdnum 
save esum_Table_8_CMF_4, replace
restore

bys ind: egen tvsTot=sum(tvs)
bys ind: egen iptTot=sum(ipt)
bys ind: egen tvsTotPos=sum(tvs*iptPos)       /* Note how all the statistics are weighted by the total value of shipments of the plant */
bys ind: egen siptPos=sum(iptPos)
bys ind: keep if _n==1 
gen plantsWithPos=siptPos/plants
gen fractionIPT=iptTot/tvsTot
gen fractionIPTonlyPos=iptTot/tvsTotPos

keep ind fraction* plantsWithPos*
outsheet using tab8_CMF_4.csv, replace delim(,)

insheet using ipt9297.csv, clear  /* Same things as above, but now the analysis is done at the 2-digit level.  */ 
replace ipt=tvs if ipt>tvs
keep if ind>=2000 & ind<=3999
gen iptPos=(ipt>0 & ipt<.)
gen ind2=floor(ind/100)
drop ind
ren ind2 ind
replace ind=20 if ind==21  
/* There are insufficiently many firms in the Tobacco 2-digit industry, SIC 21.
  Fold this industry into the Food & Kindred Products Industry */
bys ind: gen plants=_N
bys ind firmid iptPos: gen first=1 if _n==1
bys ind: egen s1=sum(first*iptPos)
bys ind: egen s2=sum(first*(1-iptPos))
replace s2=. if s2==0
replace s1=. if s1==0
keep if s1>=`cutoff' & s2>=`cutoff' 

preserve
keep firmid ind iptPos tvs lbdnum 
save esum_Table_8_CMF_2, replace
restore

bys ind: egen tvsTot=sum(tvs)
bys ind: egen iptTot=sum(ipt)
bys ind: egen tvsTotPos=sum(tvs*iptPos)
bys ind: egen siptPos=sum(iptPos)
bys ind: keep if _n==1 
gen plantsWithPos=siptPos/plants
gen fractionIPT=iptTot/tvsTot
gen fractionIPTonlyPos=iptTot/tvsTotPos
keep ind fraction* plantsWithPos*
outsheet using tab8_CMF_2.csv, replace delim(,)

insheet using cmf1992int.csv, clear
gen year=1992
save internalcmf, replace
insheet using cmf1997int.csv, clear
gen year=1997
append using internalcmf
drop if lbdnum==.
ren totalval totalval2
save internalcmf, replace 

forvalues sect=2(2)4 {  /* Loop over whether the analysis is done at the 2-digit level or at the 4-digit level */

foreach suff of local list`sect' {  /* Loop over the different methods of identifying vertically linked industries */  
foreach pref of local pref`sect' {  /* Loop over the different methods of identifying internal shipments (actually there is only one method, here) */

di "`sect' `suff' `pref'"
insheet using `pref'`suff'.csv, clear
gen vsManuf=0
replace vsManuf=vs if sicdown>=2000 & sicdown<4000
gsort rec_num year -vsManuf  /* Want to keep the -> Manuf. shipment, if one exists */
by rec_num year: gen x=_n
keep if rec_num==. | x==1
drop x
sort lbdnum year
by lbdnum year: gen fi=1 if _n==1
gen val=vs*cfs_wgt
gen valManuf=vsManuf*cfs_wgt
collapse (sum) val valManuf  (min) ships  totalval sic4 firmid emp, by(lbdnum year)
replace year=1992 if year==1993
gen viS=1
merge 1:1 lbdnum year using internalcmf
tab _merge
ren _merge mergeCMF
merge 1:1 lbdnum year using cfsSmall
replace totalval=totalval3 if totalval==. & totalval3~=.
replace val=0 if val==. & (cfssamp==1 |  _merge==2 )
replace sic4=sicCFS if sicCFS~=. & sic4==.
replace valManuf=0 if val==0 & valManuf==.
gen frac=val/totalval
gen fracManuf=valManuf/totalval  /* Here, the term Manuf denotes that we are only looking for internal shipments for which the receiving plant is in manufacturing */
drop if (_merge==1 | frac==.) 
replace viS=0 if viS==.

gen ltotalval=log(totalval)
gen ltvs=log(tvs)
cor ltvs ltotalval if viS==1
gen esum1=1 if viS==1  & ltvs~=. & ltotalval~=.
local r1=r(N)
local r2=r(rho) 
reg ltvs ltotalval if viS==1
local r3=_b[ltotalval]
local r4=_se[ltotalval] 

gen lintCMF=log(ipt)
gen lintCFS=log(val)
gen lintCFSManuf=log(valManuf)
cor lintCMF lintCFS if viS==1
gen esum2=1 if viS==1  & lintCMF~=. & lintCFS~=.
local s1=r(N)
local s2=r(rho)
reg lintCMF lintCFS if viS==1
local s3=_b[lintCFS]
local s4=_se[lintCFS] 

cor lintCMF lintCFSManuf if viS==1
gen esum3=1 if viS==1 & lintCMF~=. & lintCFSManuf~=.
local t1=r(N)
local t2=r(rho)
reg lintCMF lintCFSManuf if viS==1
local t3=_b[lintCFSManuf]
local t4=_se[lintCFSManuf] 

gen share1=ipt/tvs if sic4<=3999 & sic4>=2000 & cfssamp~=.
cor share1 frac if viS==1
gen esum4=1 if viS==1 & share1~=. & frac~=.
local u1=r(N)
local u2=r(rho)
reg share1 frac if viS==1
local u3=_b[frac]
local u4=_se[frac]

cor share1 fracManuf if viS==1
local v1=r(N)
local v2=r(rho)
reg share1 fracManuf if viS==1
gen esum5=1 if viS==1 & share1~=. & fracManuf~=.
local v3=_b[fracManuf]
local v4=_se[fracManuf]

gen sic2=floor(sic4/100)
replace sic2=floor(sic4/10) if sic4>=5000 & sic4<=5199
replace sic2=20 if sic2==21
gen pos=(frac>0 & frac<.)
bys sic`sect': egen sval=sum(totalval)
bys sic`sect': egen svalVI=sum(totalval*viS)
gen group=1 if viS==0
bys sic`sect': egen svalPos=sum(totalval*pos)
gen fracVI=svalVI/sval
gen fracPos=svalPos/sval
replace group=2 if viS==1 & pos==0
gen frac3=frac if pos==1
gen frac2=frac if viS==1
replace group=3 if pos==1
sort sic`sect' group firmid 
by sic`sect' group firmid : gen firm=1 if _n==1   
by sic`sect' group: egen ff=sum(firm)
replace ff=ff+5 if group<3
by sic`sect': egen ff2=min(ff)
save tab8_both_disclose_and_no_disclose_`pref'_`suff', replace
keep if ff2>=`cutoff'

local w1=0
local w2=0
local w3=0
local w4=0
if "`sect'"=="4" & "`pref'"=="two" & "`suff'"=="10" {
  qui sum viS 
  local w1=r(mean)
  qui sum viS [aw=totalval]
  local w2=r(mean)
  qui sum viS  if sic4==1221 |sic4==1222 |sic4==2086 |sic4==2865 |sic4==2869 |sic4==2911 |sic4==3143 |sic4==3241 |sic4== 3714 |sic4==3724 |sic4==5171 |sic4==5172 
  local w3=r(mean)
  qui sum viS  if sic4==1221 |sic4==1222 |sic4==2086 |sic4==2865 |sic4==2869 |sic4==2911 |sic4==3143 |sic4==3241 |sic4== 3714 |sic4==3724 |sic4==5171 |sic4==5172 [aw=totalval]
  local w4=r(mean)
}

preserve
keep esum* firmid emp sic`sect' group* lbdnum year
save esum_Industry_`sect'_`suff', replace
restore

by sic`sect': egen totalvalV=sum(totalval)

collapse (min) fracVI fracPos totalvalV (mean) frac frac2  frac3 [aw=totalval], by(sic`sect')

gen coef1=.
gen coef2=.
gen coef3=.
gen coef4=.
gen coef5=.
gen coef6=.

forvalues x=1/4 {
  replace coef1=`r`x'' in `x'/`x'
  replace coef2=`s`x'' in `x'/`x'
  replace coef3=`t`x'' in `x'/`x'
  replace coef4=`u`x'' in `x'/`x'
  replace coef5=`v`x'' in `x'/`x'
  replace coef6=`w`x'' in `x'/`x'
}

outsheet using tab8_`pref'_`suff'_`sect'.csv, replace delim(,)
 }
 }
}
}

/* Table 2 */
if `tab2'==1 {
insheet using  two10.csv, clear  /* Construct a dataset of the employment that each VI plant has.  This dataset is only constructed for disclosure purposes, so that we can 
                    compute the 2-firm concentration ratios (in terms of employment) of the requested output */
replace year=1992 if year==1993
keep cfn year emp
bys cfn year: keep if _n==1
save empsdset, replace
insheet using upstream10_WSTCC.csv, clear  /* First, save the total material purchases by each plant in each year,  
                                                at the 2 or 4 digit level */
gen year=1992
merge n:1 cfn year using empsdset , keep(1 3)  /* Merge in the employment data */
drop _merge 
gen totalval=vs*cfs_wgt
gen mat2=floor(stcc/1000)
gen mat4=floor(stcc/10)
collapse (sum) totalval emp, by(firmid cfn year mat2 mat4)
tostring mat4 mat2, replace force
replace mat4="0"+mat4 if length(mat4)<4
replace mat2="0"+mat2 if length(mat4)<2
save us_WSTCC_4, replace
collapse (sum) totalval emp, by(firmid cfn year mat2)
save us_WSTCC_2, replace
 
use us_WSTCC_4  /* Now sum over all plants within each firm */
collapse (sum) totalval, by(firmid year mat2 mat4)
tostring mat4 mat2, replace force
replace mat4="0"+mat4 if length(mat4)<4
replace mat2="0"+mat2 if length(mat4)<2
save us_WSTCC_4_Firm, replace
collapse (sum) totalval, by(firmid year mat2)
save us_WSTCC_2_Firm, replace  /* These datasets now contains the total amount shipped (of different 2 or 4-digit goods) by the upstream plants of each firm. In table 2 the  denominator 
     (used when computing the internal shares will be the minimum of two terms.  The amount shipped is one of these 2 terms.  */
insheet using materials_use.csv, clear
replace mc=mc*1000  /* In the CFS, values are stated in terms of thousands of dollars; in the CMF, they are stated in 
                       terms of dollars.  This line of code corrects for this discrepency */
drop lbdnum
save materials_use, replace

/* The other term, when computing the denominator, is the total amount purchased (of each 2 or 4-digit material, by the downstream plants of the firm.  Below, we compute these values. */

use materials_use, replace   /* Create a dataset of total materials purchases by each firm */
bys cfn year: keep if _n==1
gen allmats=cp+cr+cf+ee+cw
replace allmats=allmats*1000
bys cfn year: keep if _n==1
drop mc m
ren allmats mc
gen mat0="000000"  
save materialFirm_0, replace

use materials_use, replace /* Create a dataset of total materials purchases, for each 4-digit material, by each firm */
gen mat4=substr(m,1,4)
collapse (sum) mc, by(firmid cfn mat4 year)
drop if mat4==""
drop if year==1997
save materialFirm_4, replace

use materials_use, replace /* Create a dataset of total materials purchases, for each 2-digit material, by each firm. */
gen mat2=substr(m,1,2)
collapse (sum) mc, by(firmid cfn mat2 year)
drop if mat2==""
drop if year==1997
save materialFirm_2, replace

insheet using downstreamplants10.csv, clear  /* This dataset, which we are reading in, contains the list of downstream plants 
                                        for each firm, in 1992.   */
gen year=1992
save down10, replace
insheet using downstreamplants10_97.csv, clear
gen year=1997 
append using down10
sort cfn year
by cfn year: keep if _n==1
save down10, replace    

forvalues x=0(2)4 {
use down10, replace
ren cfndown cfn
merge 1:n cfn year using materialFirm_`x'     

drop if _merge==1  /* Merge=1 for nonmanufacturing establishments- since they do not fill out information on materials purchasese */
if `x'==0 {               /* Here, and below, the x is used to denote the level of industry aggregation under which the analysis is performed.  If x=0, then we look at all materials (without breaking out different materials) */
  drop if _merge==2    /* Merge=2 for establishments that are not identified as downstream establishments (according to our algorithm for idnetifying vertical relationships) */
}
drop _merge
sort firmid year mat`x'
egen firmallmats=total(mc), by(firmid year mat`x')  
ren lbdnumd lbdnum 
keep firmallmats cfn lbdnum year firmid mat`x'
bys firmid mat`x' year: keep if _n==1
save materialFirm_`x', replace  /* This dataset now tells us how much is purchased by each firm's downstream plants at the 0/2/4-digit level of aggregation.  */
}

insheet using allInFirm_IOIND.csv, clear   /* The IOIND suffix denotes that we keep plants in firmXioindXyear combinations such that all of the plants in that firmXioindXyear  were sampled in that years Commodity Flow Survey.  */
cap tostring cfn , replace force
drop if ioind==.
save allInFirm_IOIND, replace

foreach suff in  /*Orig 50 10NH 50NH*/ 10 {

insheet using two`suff'.csv, clear
replace year=1992 if year==1993
save two`suff', replace 

local counter=`counter'+1
local count=0
forvalues x=0(2)4 {
local count=`count'+1
use two`suff', replace
sort rec_num year
by rec_num year: gen x=_n
keep if x==1 | rec_num==.
drop x
gen val=vs*cfs_wgt
replace val=0 if val==.
bys cfn year: replace totalval=0 if _n>1  /* This variable will only stick around in the x=0 case.  For this case, replace all-but-one of the values of totalval to 0, since we are going 
                                             to sum up over all observations for the plant-year */
if `x'==0 {
  gen mat`x'="000000"  /* Generate a fake material code in the case for which we are summing up over all observations for the plant-year */
}
if `x'~=0 {
  gen mat`x'=substr(string(stcc),1,`x')
  drop if rec_num==.
}
collapse (sum) val totalval (min) firmid emp, by(cfn year mat`x')
if `x'~=0 {
  drop totalval
  merge 1:1 cfn firmid year mat`x' using us_WSTCC_`x'  
  drop if _merge==1 /* Merge=1 appears almost exclusively in 1997, when we don't have info on the amount shipped of each good (because of a change in 
                     the definition of CFS product codes from STCC to SCTG. The other cases of _merge=1 occur when primary materials (which have a 2-digit material code<20) are being shipped. */
  replace val=0 if val==.    /* val=. when _merge=2 (i.e., when some upstream plant produced the good in question, but where there is no internal shipments in that paricular upstream plant-year */
  drop _merge
}
replace year=1992 if year==1993
joinby cfn year using allInFirm_IOIND
collapse (sum) val totalval  emp, by(firmid year mat`x')   /* The unit of observation will be firmXyearXmaterial.  
    Note that this is different from table 1, where the unit of observation was plantXyear */
merge 1:1 firmid year mat`x' using materialFirm_`x', keep(1 3)

if `x'==2 | `x'==4 {
  drop if year==1997  /* Again, the CFS product codes change between 1992 and 1997.  It would be possible to match SCTG codes with STCC codes, so that we wouldn't 
           have to drop data from 1997.*/
}

replace firmallmats=0 if _merge==1  /* Firmallmats will be 0 if there are no downstream plants in the firm that purchase the `x' digit material.  These observations will be dropped, so this
  line of code is baseically unnecessary.   */
drop _merge

if `x'==2 | `x'==4 {
  merge 1:n firmid year mat`x' using  us_WSTCC_`x'_Firm  
  keep if _merge==3  /* Here _merge==2 if not all of the plants in the firmXioind are sampled in the Commodity Flow Survey.  Drop these observations.  */
  drop _merge
}

gen share=val/min(totalval, firmallmats)
keep if share~=.
save samp`x', replace
_pctile share, p(9 11  24  26 49 51 74 76  89  91 94 96)
gen esum=1 if share~=.

preserve
keep share esum firmid emp  lbdnum year
save esum_tab2_`suff'_`x', replace
restore

forvalues xxx=1/6 {
  local y=`xxx'*2-1
  local yy=`xxx'*2
  local store`count'_`xxx'=1/2*(r(r`y')+r(r`yy')) in `xxx'/`xxx'
}
  count if share==0
  local store`count'_9=r(N)
  count if share>=1
  local store`count'_10=r(N)
  sum share
  local store`count'_7=r(mean)
  local store`count'_8=r(N)
}

use samp0, replace
keep firmid year
bys firmid year : keep if _n==1
merge 1:n firmid year using two`suff'
keep if _merge==3
drop _merge
replace year=1992 if year==1993
merge n:1 lbdnum year using allInFirm_IOIND
keep if _merge==3
drop _merge
sort rec_num year
by rec_num year: gen x=_n
keep if x==1 | rec_num==.
drop x
gen val=vs*cfs_wgt
replace val=0 if val==.
gen viS=0
replace viS=1 if rec_num~=.
collapse (sum) val viS (min) totalval firmid emp ships, by(lbdnum year)
gen share= val/totalval
_pctile share, p(9 11  24  26 49 51 74 76  89  91 94 96)
gen esum=1 if share~=.
gen one=1 if viS==ships & share~=.

preserve
keep share esum firmid emp one lbdnum year
save esum_tab2_`suff', replace
restore

forvalues xxx=1/6 {
  local y=`xxx'*2-1
  local yy=`xxx'*2
  local store4_`xxx'=1/2*(r(r`y')+r(r`yy')) in `xxx'/`xxx'
}
  count if share==0
  local store4_9=r(N)
  count if viS==ships & share~=.
  local store4_10=r(N)
  sum share
  local store4_7=r(mean)
  local store4_8=r(N)

forvalues ii=1/4 {
  gen coef`ii'=. 
  forvalues jj=1/10  {
   replace coef`ii'=`store`ii'_`jj'' in `jj'/`jj'
 }
}

gen count=`counter'
keep coef* 
keep in 1/10
outsheet using tab2_`suff'.csv, replace delim(,)

}
}

/* Figure 1 */

if `fig1'==1 {
foreach suff in 10 50 10NH 50NH Orig {

insheet using two`suff'.csv, clear  
sort rec_num year
by rec_num year: gen x=_n
keep if rec_num==. | x==1
gen value=vs*cfs_wgt
collapse (sum) value (min) totalval, by(lbdnum year)
gen frac=value/total
replace frac=1 if frac>=1
hist frac, frac xtitle("Value Share of Internal Shipments") ytitle("Fraction of Establishments") color(black)
graph save figVI1_A_`suff'.gph, replace
graph export figVI1_A_`suff'.eps, replace

insheet using three`suff'.csv, clear  /* This paper does not appear in the current draft of the paper, but was Figure 1A in previous drafts. A shipment is defined as internal if the sending plant is an upstream plant and there is a downstream plant in the destination zip code, even if the two plants are not part of the same vertical link.   */
sort rec_num year
by rec_num year: gen x=_n
keep if rec_num==. | x==1
gen value=vs*cfs_wgt
collapse (sum) value (min) totalval, by(lbdnum year)
gen frac=value/total
replace frac=1 if frac>=1
hist frac, frac xtitle("Value Share of Internal Shipments") ytitle("Fraction of Establishments") color(black)
graph save figVI1_C_`suff'.gph, replace
graph export figVI1_C_`suff'.eps, replace

insheet using three`suff'A.csv, clear
sort rec_num year
by rec_num year: gen x=_n
keep if rec_num==. | x==1
gen value=vs*cfs_wgt
bys lbdnum year: egen sval=sum(val)
collapse (sum) value (min) totalval, by(lbdnum year)
gen frac=value/total
replace frac=1 if frac>=1
hist frac, frac xtitle("Value Share of Internal Shipments") ytitle("Fraction of Establishments") color(black)
graph save figVI1_B_`suff'.gph, replace
graph export figVI1_B_`suff'.eps, replace
}
}

/* Table A3 */
if `tab3'==1 {
foreach suff in  10    {

insheet using table5to7_`suff'.csv, clear
keep ppn year ar vi sic4 ioind tvs firmid 
sort ppn year
by ppn year: keep if _n==1
save bunk, replace  

* Use materials data already cleaned of material codes starting with "9" (balancing codes)
insheet using cmmat.csv, clear
sort ppn year
merge n:1 ppn year using bunk
keep if _merge==3 & ar==0 & mc>0
drop _merge ar

gen paragraph1=.
gen paragraph2=.
gen paragraph3=.
gen table1=.
gen table2=.
gen table3=.
gen table4=.
gen table5=.

egen ppnyrtag=tag(ppn year)
tostring ioind, replace force
gen ioindyr=ioind+string(year)
gen ioindmatyr=ioind+m+string(year)
gen raw=(mfirstdig<=1)
gen novi=(vi==0)
gen rawmc=raw*mc
gen vimc=vi*mc
gen virawmc=vi*raw*mc
gen novimc=novi*mc
gen novirawmc=novi*raw*mc
gen vippncp=vi*ppnyrtag*cp
gen novippncp=novi*ppnyrtag*cp
egen ppnrawmc=total(rawmc), by(ppn year)
egen ppnmatuse=total(mc), by(ppn year)
gen vippnmatuse=vi*ppnmatuse
gen novippnmatuse=novi*ppnmatuse

gen ppnrawmatshr=ppnrawmc/cp
gen ppnrawmatshr2=ppnrawmc/ppnmatuse

egen viindrawuse=total(virawmc), by(ioindyr)
egen viinduse=total(vippncp), by(ioindyr)
egen viinduse2=total(vippnmatuse), by(ioindyr)
egen noviindrawuse=total(novirawmc), by(ioindyr)
egen noviinduse=total(novippncp), by(ioindyr)
egen noviinduse2=total(novippnmatuse), by(ioindyr)
egen ioindyrtag=tag(ioindyr)
gen viindrawshr=viindrawuse/viinduse
gen viindrawshr2=viindrawuse/viinduse2
gen noviindrawshr=noviindrawuse/noviinduse
gen noviindrawshr2=noviindrawuse/noviinduse2
gen indrawshrdiff=viindrawshr-noviindrawshr
gen indrawshrdiff2=viindrawshr2-noviindrawshr2

drop if indrawshrdiff2==.

* Tests to see if raw materials shares are the same across VI and non-VI plants in same industry-year
* Define raw aterials as those from ag, forestry, fishing, and mining sectors
sum ppnrawmatshr if ppnyrtag==1, d
sum ppnrawmatshr if ppnrawmatshr<=1 & ppnyrtag==1, d
sum ppnrawmatshr2 if ppnyrtag==1, d
local locvar7=r(mean)
sum ppnrawmatshr2 if ppnyrtag==1 & ppnrawmatshr2>0 & ppnrawmatshr2<., d
local locvar8=r(mean)

areg ppnrawmatshr vi if ppnrawmatshr<=1 & ppnyrtag==1, r a(ioindyr)
areg ppnrawmatshr2 vi if ppnrawmatshr2<=1 &  ppnyrtag==1, r a(ioindyr)

local locvar1=e(N)
local locvar2=_b[vi]
local locvar3=_se[vi]

areg ppnrawmatshr vi if ppnrawmatshr>0 & ppnrawmatshr<=1 & ppnyrtag==1 , r a(ioindyr)
areg ppnrawmatshr2 vi if ppnrawmatshr2>0 & ppnrawmatshr2<=1 & ppnyrtag==1, r a(ioindyr) 
local locvar4=e(N)
local locvar5=_b[vi]
local locvar6=_se[vi]

gen esumPara1_1=1 if vi==1  & ppnrawmatshr2==0 
gen esumPara1_2=1 if vi==0  & ppnrawmatshr2==0 
gen esumPara1_3=1 if vi==1 & ppnrawmatshr2~=0 & ppnrawmatshr2~=. 
gen esumPara1_4=1 if vi==0 & ppnrawmatshr2~=0  & ppnrawmatshr2~=.
* Do similar for industry-level shares (aggregate vi and non-vi plants' usage) 
sum *viindrawshr* if ioindyrtag==1 
reg indrawshrdiff if ioindyrtag==1, r  
sort ioindyr 
reg indrawshrdiff2 if ioindyrtag==1, r
gen esumPara2_1=1 if indrawshrdiff2~=.
replace paragraph2=e(N) in 1/1
replace paragraph2=_b[_cons] in 2/2
replace paragraph2=_se[_cons] in 3/3
* Compare aggregate shares across VI and non-VI plants within industry-materials pairs
egen viindmatuse=total(vimc), by(ioindmatyr)
egen noviindmatuse=total(novimc), by(ioindmatyr)
egen ioindmatyrtag=tag(ioindmatyr)
gen viindmatuseshr=viindmatuse/viinduse
gen viindmatuseshr2=viindmatuse/viinduse2
gen noviindmatuseshr=noviindmatuse/noviinduse
gen noviindmatuseshr2=noviindmatuse/noviinduse2

* Compute materials' share-rankings by VI and no-VI for each industry-year 
egen viindmatuseshrrank=rank(viindmatuseshr) if ioindmatyrtag==1, f by(ioindyr)
egen viindmatuseshrrank2=rank(viindmatuseshr2) if ioindmatyrtag==1, f by(ioindyr)
egen noviindmatuseshrrank=rank(noviindmatuseshr) if ioindmatyrtag==1, f by(ioindyr)
egen noviindmatuseshrrank2=rank(noviindmatuseshr2) if ioindmatyrtag==1, f by(ioindyr)

egen matperind=total(ioindmatyrtag), by(ioindyr)
sum matperind if ioindyrtag==1, d
replace viindmatuseshrrank=0 if  ppnrawmatshr2~=. & viindmatuseshrrank==.
replace noviindmatuseshrrank=0 if  ppnrawmatshr2~=. & noviindmatuseshrrank==.

corr viindmatuseshrrank noviindmatuseshrrank if ioindmatyrtag==1 
corr viindmatuseshrrank2 noviindmatuseshrrank2 if ioindmatyrtag==1 
replace paragraph3=r(rho) in 1/1
replace paragraph3=r(N) in 2/2
gen esumPara3_1=1 if viindmatuseshr2~=. &  viindmatuseshr2~=. 
forvalues ggg=1/8 {
  replace paragraph1=`locvar`ggg'' in `ggg'/`ggg'
}
tab viindmatuseshrrank noviindmatuseshrrank if noviindmatuseshrrank<=5 & ioindmatyrtag==1, matcell(mat1)
tab noviindmatuseshrrank if viindmatuseshrrank~=. &  ioindmatyrtag==1, matcell(mat2)
tab viindmatuseshrrank2 noviindmatuseshrrank2 if noviindmatuseshrrank<=5 & ioindmatyrtag==1, matcell(mat3)
tab noviindmatuseshrrank2 if viindmatuseshrrank2~=. &  ioindmatyrtag==1, matcell(mat4)

forvalues x=1/5 {
  forvalues y=1/7{
   replace table`x'=mat1[`y',`x']/mat2[`x',1] in `y'/`y'  
   gen esum_Table_`x'_`y'=1 if noviindmatuseshrrank2==`x' &  viindmatuseshrrank2==`y'
 }
}
 
preserve
keep esum* tvs firmid ppn year m
save esumTable3_`suff', replace
restore

count   if ioindmatyrtag==1 & viindmatuseshrrank~=. & noviindmatuseshrrank<=5
replace paragraph3=r(N) in 3/3

keep table* paragraph*
keep in 1/8
outsheet using table3_`suff'.csv, replace delim(,)
}
}

/* Calculation on establishments that make their firm vertically integrated */

if `makeVI'==1  {
foreach suff in 10 /*Orig*/ {

insheet using fig2_`suff'.csv, clear
drop if mu==. 
sort firmid year
by firmid year: egen VI=max(vi)
sort lbdnum  year
gen newvinewup=0
replace newvinewup=1 if year>=1992 & vi==1 & VI[_n-1]==0 & mu==1 & mu[_n-1]==0 & lbdnum==lbdnum[_n-1]
keep if year>=1992 & vi==1
keep firmid lbdnum year  newvinewup
bys lbdnum year: keep if _n==1
save newvinewmu, replace  
insheet using two`suff'.csv, clear
bys rec_num year: gen fi=1 if _n==1
gen val=vs*cfs_wgt
keep if fi==1 | rec_num==.
gen intships=1 if rec_num~=.
collapse (sum) val intships (min) firmid  sic4 totalval ships emp , by(lbdnum year )
gen frac=val/totalval
replace year=1992 if year==1993
merge 1:1 lbdnum year using newvinewmu, keep(1 3)
drop _merge
merge n:1 sic4 using sicIOmatch, keep(1 3)
destring ioind, replace 
gen double xt1=mod(year,100)+ioind*10000

gen coef1=.
areg frac newvinewup , r a(xt1)
replace coef1=_b[newvinewup] in 13/13
replace coef1=_se[newvinewup] in 14/14

sum frac if newvinewup==1, detail
replace coef1=r(mean) in 7/7
replace coef1=r(N) in 8/8
sum frac if newvinewup==1 [aw=totalval]
replace coef1=r(mean) in 12/12
_pctile frac if newvinewup==1 , p(8 12  23 27 48 52 73 77  88  92 93 97)

gen esum=1 if frac~=. & newvinewup
gen one=1 if intships==ships & newvinewup==1
preserve
keep frac esum emp one newvinewup firmid lbdnum year
save esum_makevi_`suff', replace
restore

forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef1=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
count if frac==0 &  newvinewup==1
replace coef1=r(N) in 9/9
count if intships==ships &  newvinewup==1
replace coef1=r(N) in 10/10
sum ships if frac~=. & newvinewup==1
replace coef1=r(sum) in 11/11
keep in 1/14
keep coef1
outsheet using makevi_`suff'.csv, replace 
}
}

/* Tables 3-5, A5-A6.  Table 3-5 correspond to the case in which suff=10; Tables A5-A6 correspond to the case in which suff=50. */
if `tab5'==1 {
forvalues outlier = 0/0 {
foreach suff in 10  50 /* Orig */ {

insheet using table5to7_`suff'.csv, clear
gen double xt=mod(year,100)+ioind*10000   /* Create group variable BEA industry X year */
xtset xt
set more off

sort ppn year
by ppn : gen new=1 if _n==1 & year>1977  
replace new=0 if new==. & year>1977

sort ppn year
gen tobe=1 if ppn==ppn[_n+1] & year[_n+1]-year==5 & vi[_n+1]==1 & vi==0 & ar==0  /* Indicator variable, equal to 1 if the plant will be an upstream end of a vertical plant in the next CM */
replace tobe=0 if ppn==ppn[_n+1] & year[_n+1]-year==5 & vi[_n+1]==0 & vi==0 & ar==0

sort ppn year
gen newvi=1 if vi==1 & vi[_n-1]==0 & ppn==ppn[_n-1] & year-year[_n-1]==5  & ar==0
replace newvi=0 if vi==0 & vi[_n-1]==0 & ppn==ppn[_n-1] & year-year[_n-1]==5  & ar==0

gen mi=(industriesfirm>1)  /* Multi-industry dummy variable */
gen si=1-mi

gen miWithout=(industriesfirm>2 | ( industriesfirm>1 & establishmentsind>1  ) ) 
gen siWithout=1-miWithout

gen coef1=.
gen coef2=.
gen coef3=.
gen coef4=.

local count=0
sort ppn year

replace industriesfirm=log(industriesfirm)
replace employmentfirm=log(employmentfirm)
replace establishmentsfirm=log(establishmentsfirm)
gen empWithoutSelf=log(exp(employmentfirm)-emp)
gen estWithoutSelf=log(exp(establishmentsfirm)-1)
gen indWithoutSelf=log(industriesfirm-(establishmentsind==1 ))

forvalues x=2/5 {
   foreach var of varlist industriesfirm employmentfirm establishmentsfirm  *WithoutSelf {
      gen `var'`x'x=(`var')^`x'
  }
}
gen lnpw=log(te-pw)  /* Note that there are quite a few missing values here: for plants that only have production workers, te will be equal to pw (and so lnpw will be equal to 0) */
gen lpw=log(pw)
gen lph=ly-llabor
gen samp1=1   /* For Table 5, we want all of the production measures to be nonmissing.  If any of the production measures are missing, set the samp1 to 0 */
gen samp2=1
foreach var of varlist lph ly lkpe lk  llabor lpw lnpw npwr tfp {
   gen d`var'=`var'-`var'[_n-1] if ppn==ppn[_n-1] & year-year[_n-1]==5 & ar==0 & ar[_n-1]==0
   replace samp1=0 if d`var'==.
   gen D`var'=`var'[_n+1]-`var'[_n-1] if ppn[_n+1]==ppn[_n-1] & year[_n+1]-year[_n-1]==10 & ar[_n+1]==0 & ar[_n-1]==0
   replace samp2=0 if D`var'==.
   drop d`var' D`var'
}

gen coef7=.  /* This variable will store the regression results of Table 5 */
gen coef7_Long=.  /* This variable will store the same regression results, but using a longer time horizon */

local c=1  /* c is a counter variable */

gen footnote19=.
gen k=exp(lk)
gen labor=exp(llabor)
qui sum k
local ests=r(N)
local kap=r(sum)
qui sum labor 
local lab=r(sum)
sort ppn year
qui sum k if mu==1

gen esum19Mu1=1 if mu==1  
gen esum19Mu0=1 if mu==0
gen esum19Vi1=1 if vi==1  
gen esum19Vi0=1 if vi==0
gen esum19Si1=1 if mi==1   & mu==1
gen esum19Si0=1 if mi==0   & mu==1
gen esum19Ni1=1 if vi==1   & mu==1
gen esum19Ni0=1 if vi==0   & mu==1

replace footnote19=r(N)/`ests' in 1/1
replace footnote19=r(sum)/`kap' in 3/3
qui sum lab if mu==1
replace footnote19=r(sum)/`lab' in 2/2

qui sum k if vi==1
replace footnote19=r(N)/`ests' in 4/4
replace footnote19=r(sum)/`kap' in 6/6
qui sum lab if vi==1
replace footnote19=r(sum)/`lab' in 5/5

qui sum k if mu==1 & mi==0
replace footnote19=r(N)/`ests' in 7/7
replace footnote19=r(sum)/`kap' in 9/9
qui sum lab if mu==1 & mi==0
replace footnote19=r(sum)/`lab' in 8/8

qui sum k if mi==1 & vi==0
replace footnote19=r(N)/`ests' in 10/10
replace footnote19=r(sum)/`kap' in 12/12
qui sum lab if mi==1 & vi==0
replace footnote19=r(sum)/`lab' in 11/11

sort xt
if `outlier'==1 {
   foreach var of varlist lph ly lkpe lk  llabor lpw lnpw npwr tfp {
     by xt: egen top=pctile(`var'), p(99)
     by xt: egen bot=pctile(`var'), p(1)
     replace `var'=top if `var'>=top & `var'<.
     replace `var'=bot if `var'<=bot
     drop top bot
  }  
}

sort ppn year
foreach var of varlist lph ly lkpe lk  llabor lpw lnpw npwr tfp {
  local c=`c'+1
  gen D`var'=`var'[_n+1]-`var'[_n-1] if ppn[_n+1]==ppn[_n-1] & year[_n+1]-year[_n-1]==10 
  areg D`var' newvi if samp2==1 & newvi~=. & ar[_n+1]==0, r a(xt)
  replace coef7_Long=_b[newvi] in `c'/`c'
  local c=`c'+1
  replace coef7_Long=_se[newvi] in `c'/`c'
  local c=`c'-1
  gen d`var'=`var'-`var'[_n-1] if ppn==ppn[_n-1] & year-year[_n-1]==5
  areg d`var' newvi if samp1==1 & newvi~=. & ar==0, r a(xt)
  replace coef7=_b[newvi] in `c'/`c'
  local c=`c'+1
  replace coef7=_se[newvi] in `c'/`c'
  drop d`var' D`var'
}

count if newvi==1 & e(sample)==1
local c=`c'+1
gen esum_5to7_7_1=1 if e(sample)==1 & newvi==1
gen esum_5to7_7_0=1 if e(sample)==1 & newvi==0
replace coef7=r(N) in `c'/`c'
count if e(sample)==1
replace coef7=r(N) in 1/1
qui gen Dly=ly[_n+1]-ly[_n-1] if ppn[_n+1]==ppn[_n-1] & year[_n+1]-year[_n-1]==10
qui areg Dly newvi if samp2==1 & newvi~=. & ar[_n+1]==0, r a(xt)
qui drop Dly
gen esum_5to7_7_3=1 if e(sample)==1 & newvi==1
gen esum_5to7_7_2=1 if e(sample)==1 & newvi==0
count if newvi==1 & e(sample)==1 
replace coef7_Long=r(N) in `c'/`c'
count if  e(sample)==1 
replace coef7_Long=r(N) in 1/1

foreach var of varlist lph tfp ly lkpe {
  gen d`var'=`var'-`var'[_n-1] if ppn==ppn[_n-1] & year-year[_n-1]==5 & ar==0 & ar[_n-1]==0
  gen D`var'=`var'[_n+1]-`var'[_n-1] if ppn[_n+1]==ppn[_n-1] & year[_n+1]-year[_n-1]==10 & ar[_n+1]==0 & ar==0 & ar[_n-1]==0
  local count=`count'+1
  areg `var' vi if ar==0, r a(xt)
  gen esum_5to7_`count'_Reg1_1=1 if e(sample)==1 & vi==1
  gen esum_5to7_`count'_Reg1_0=1 if e(sample)==1 & vi==0
  replace coef`count'=e(N) in 1/1
  replace coef`count'=_b[vi] in 2/2
  replace coef`count'=_se[vi] in 3/3
  count if vi==1 & e(sample)==1
  replace coef`count'=r(N) in 4/4
  areg `var' vi if new==1 & ar==0, r a(xt)
  gen esum_5to7_`count'_Reg2_1=1 if e(sample)==1 & vi==1
  gen esum_5to7_`count'_Reg2_0=1 if e(sample)==1 & vi==0
  replace coef`count'=e(N) in 5/5
  replace coef`count'=_b[vi] in 6/6
  replace coef`count'=_se[vi] in 7/7
  count if vi==1 & e(sample)==1
  replace coef`count'=r(N) in 8/8
  areg `var' tobe if tobe~=. & ar==0, r a(xt)
  gen esum_5to7_`count'_Reg3_1=1 if e(sample)==1 & tobe==1
  gen esum_5to7_`count'_Reg3_0=1 if e(sample)==1 & tobe==0
  replace coef`count'=e(N) in 9/9
  replace coef`count'=_b[tobe] in 10/10
  replace coef`count'=_se[tobe] in 11/11
  count if tobe==1 & e(sample)==1
  replace coef`count'=r(N) in 12/21
  areg d`var' newvi if newvi~=. & ar==0, r a(xt)
  gen esum_5to7_`count'_Reg4_1=1 if e(sample)==1 & newvi==1
  gen esum_5to7_`count'_Reg4_0=1 if e(sample)==1 & newvi==0
  replace coef`count'=e(N) in 13/13
  replace coef`count'=_b[newvi] in 14/14
  replace coef`count'=_se[newvi] in 15/15
  count if newvi==1 & e(sample)==1
  replace coef`count'=r(N) in 16/16

  areg D`var' newvi if newvi~=. & ar==0, r a(xt)
  gen esum_5to7_`count'_Reg8_1=1 if e(sample)==1 & newvi==1
  gen esum_5to7_`count'_Reg8_0=1 if e(sample)==1 & newvi==0
  replace coef`count'=e(N) in 31/31
  replace coef`count'=_b[newvi] in 32/32
  replace coef`count'=_se[newvi] in 33/33
  count if newvi==1 & e(sample)==1
  replace coef`count'=r(N) in 34/34

  areg `var' vi mi if ar==0, r a(xt)
  gen esum_5to7_`count'_Reg5_1=1 if e(sample)==1 & vi==1
  gen esum_5to7_`count'_Reg5_0=1 if e(sample)==1 & vi==0
  gen esum_5to7_`count'_Reg5_2=1 if e(sample)==1 & mi==1
  gen esum_5to7_`count'_Reg5_3=1 if e(sample)==1 & mi==0
  replace coef`count'=e(N) in 17/17
  replace coef`count'=_b[vi] in 18/18
  replace coef`count'=_se[vi] in 19/19
  replace coef`count'=_b[mi] in 20/20
  replace coef`count'=_se[mi] in 21/21 
  count if vi==1 & e(sample)==1
  replace coef`count'=r(N) in 22/22
  areg `var' vi  si establishmentsfirm* employment* industr* if ar==0 & mu==1, r a(xt)  /* In the old draft of the paper, only MU plants were included in the final set of regressions in Table 4.  
                       As before, look at the mu-only subsample...  */
  gen esum_5to7_`count'_Reg6_1=1 if e(sample)==1 & vi==1
  gen esum_5to7_`count'_Reg6_0=1 if e(sample)==1 & vi==0
  replace coef`count'=e(N) in 23/23
  replace coef`count'=_b[vi] in 24/24
  replace coef`count'=_se[vi] in 25/25
  count if vi==1 & e(sample)==1
  replace coef`count'=r(N) in 26/26
  areg `var' vi  si establishmentsfirm* employment* industr* if ar==0 , r a(xt)  /*... But also look at single-unit plants  */
  gen esum_5to7_`count'_Reg7_1=1 if e(sample)==1 & vi==1
  gen esum_5to7_`count'_Reg7_0=1 if e(sample)==1 & vi==0
  replace coef`count'=e(N) in 27/27
  replace coef`count'=_b[vi] in 28/28
  replace coef`count'=_se[vi] in 29/29
  count if vi==1 & e(sample)==1
  replace coef`count'=r(N) in 30/30
  areg `var' vi  siWithout *WithoutSelf*  if ar==0 , r a(xt)  /* Calculate firm level characteristics if own plant did not exist  */
  gen esum_5to7_`count'_Reg9_1=1 if e(sample)==1 & vi==1
  gen esum_5to7_`count'_Reg9_0=1 if e(sample)==1 & vi==0
  replace coef`count'=e(N) in 35/35
  replace coef`count'=_b[vi] in 36/36
  replace coef`count'=_se[vi] in 37/37
  count if vi==1 & e(sample)==1
  replace coef`count'=r(N) in 38/38
  areg `var' vi miWithout if ar==0 , r a(xt)
  gen esum_5to7_`count'_Reg10_1=1 if e(sample)==1 & vi==1
  gen esum_5to7_`count'_Reg10_0=1 if e(sample)==1 & vi==0
  gen esum_5to7_`count'_Reg10_2=1 if e(sample)==1 & mi==1
  gen esum_5to7_`count'_Reg10_3=1 if e(sample)==1 & mi==0
  replace coef`count'=e(N) in 39/39
  replace coef`count'=_b[vi] in 40/40
  replace coef`count'=_se[vi] in 41/41
  replace coef`count'=_b[miWithout] in 42/42
  replace coef`count'=_se[miWithout] in 43/43 
  areg `var' vi  if ar==0 & empWithoutSelf~=. & indWithoutSelf~=. & estWithoutSelf~=., r a(xt)
  gen esum_5to7_`count'_Reg11_1=1 if e(sample)==1 & vi==1
  gen esum_5to7_`count'_Reg11_0=1 if e(sample)==1 & vi==0
  gen esum_5to7_`count'_Reg11_2=1 if e(sample)==1 & mi==1
  gen esum_5to7_`count'_Reg11_3=1 if e(sample)==1 & mi==0
  replace coef`count'=e(N) in 44/44
  replace coef`count'=_b[vi] in 45/45
  replace coef`count'=_se[vi] in 46/46
 
 }

preserve
keep firmid esum* tvs lbdnum year
save esum_5to7_`suff', replace
restore

keep coef* footnote 
keep in 1/46
outsheet using table5to7_Res_`suff'_`outlier'.csv, replace delim(,)

}
}
}

/* Stuff that goes in Appendix C5 */

use sicTable10, replace
ren frac frac10
merge 1:1 sicUp sic4 using sicTable50, nogen
ren frac frac50
merge 1:1 sicUp sic4 using sicTable100, nogen
ren frac frac100
merge 1:1 sicUp sic4 using sicTable200, nogen
ren frac frac200
sort sicUp
foreach var of varlist frac* {
  replace `var'=(`var'~=.)
  by sicUp: egen s`var'=sum(`var')
}
by sicUp: keep if _n==1
keep sicUp sf*
ren sicUp sic4
save industryDefinitionCount, replace
use cfs93Small
append using cfs97Small
merge n:1 sic4 using industryDefinitionCount
drop if _merge==2
drop _merge
sort sic4
by sic4: gen fi=1 if _n==1
foreach var of varlist sf* {
  gen `var'_uw=`var'*fi
}
collapse (mean) sf* 
save industryDefinitionCountResult1, replace

use if sicUp==2061 using sicTable05, replace
gsort -frac
save industryDefinitionCountResult2, replace

/* An extra row of table 1, Panel B */

insheet using two10M2M.csv, clear
replace year=1992 if year==1993
drop if totalv==0
gen val=vs*cfs_wgt
sort rec_num year val
by rec_num year: keep if _n==1 | rec_num==.
replace cfs_wgt=1 if cfs_wgt==.
gen viS=1 if val>0 & val<.
collapse (sum) val viS (min) totalval emp ships firmid sic4, by(lbdnum year)

merge 1:1 lbdnum year using ipt9297
drop _merge

gen coef19=.
gen coef20=.
gen frac1=val/totalv
gen frac2=ipt/tvs
keep if frac1~=. & frac2~=.
sum frac1 
replace coef19= r(mean) in 7/7
replace coef19= r(N) in 8/8
sum frac1  [aw=totalval]
replace coef19= r(mean) in 12/12
count if frac1==0 
replace coef19=r(N) in 9/9
count if ships==viS & frac1~=.
replace coef19=r(N) in 10/10
gen one19=1 if viS==ships & frac1~=.
_pctile frac1 , p(9 11  24  26 49 51 74 76  89  91 94 96)
gen esum19=1 if frac1~=. 
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef19=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac1~=. 
replace coef19=r(sum) in 11/11

sum frac2 
replace coef20= r(mean) in 7/7
replace coef20= r(N) in 8/8
sum frac2  [aw=totalval]
replace coef20= r(mean) in 12/12
count if frac2==0  
replace coef20=r(N) in 9/9
count if abs(ipt-tvs)<.001  &  frac2~=.
replace coef20=r(N) in 10/10
gen one20=1 if abs(ipt-tvs)<.001
_pctile frac2 , p(9 11  24  26 49 51 74 76  89  91 94 96)
forvalues x=1/6 {
  local y=`x'*2-1
  local yy=`x'*2
  replace coef20=1/2*(r(r`y')+r(r`yy')) in `x'/`x'
}
sum ships if frac2~=. 
replace coef20=r(sum) in 11/11
keep coef19 coef20
keep in 1/12
outsheet using  table1row6.csv, replace delim(,)
